@@ -1,4 +1,4 @@
-/* Copyright (c) 1996, 1997, 1998, 1999, 2001 Thorsten Kukuk
+/* Copyright (c) 1996, 1997, 1998, 1999, 2001, 2004 Thorsten Kukuk
    Author: Thorsten Kukuk <kukuk@suse.de>
 
    The YP Server is free software; you can redistribute it and/or
@@ -49,57 +49,60 @@ static
 void _msgout(char* msg)
 {
 #ifdef RPC_SVC_FG
-	if (_rpcpmstart)
-	  log_msg (msg);
-	else
-	  fprintf (stderr, "%s\n", msg);
+  if (_rpcpmstart)
+    log_msg ("%s", msg);
+  else
+    fprintf (stderr, "%s\n", msg);
 #else
-	log_msg (msg);
+  log_msg ("%s", msg);
 #endif
 }
 
 void
-ypxfrd_freebsd_prog_1 (struct svc_req *rqstp, register SVCXPRT *transp)
+ypxfrd_freebsd_prog_1 (struct svc_req *rqstp, SVCXPRT *transp)
 {
-	union {
-		ypxfr_mapname ypxfrd_getmap_1_arg;
-	} argument;
-	char *result;
-	xdrproc_t xdr_argument, xdr_result;
-	char *(*local)(char *, struct svc_req *);
+  union {
+    ypxfr_mapname ypxfrd_getmap_1_arg;
+  } argument;
+  char *result;
+  xdrproc_t xdr_argument, xdr_result;
+  char *(*local)(char *, struct svc_req *);
 
-	_rpcsvcdirty = 1;
-	switch (rqstp->rq_proc) {
-	case NULLPROC:
-		(void) svc_sendreply(transp, (xdrproc_t) xdr_void, (char *)NULL);
-		_rpcsvcdirty = 0;
-		return;
+  _rpcsvcdirty = 1;
+  switch (rqstp->rq_proc)
+    {
+    case NULLPROC:
+      svc_sendreply(transp, (xdrproc_t) xdr_void, NULL);
+      _rpcsvcdirty = 0;
+      return;
 
-	case YPXFRD_GETMAP:
-		xdr_argument = (xdrproc_t) xdr_ypxfr_mapname;
-		xdr_result = (xdrproc_t) xdr_xfr;
-		local = (char *(*)(char *, struct svc_req *)) ypxfrd_getmap_1_svc;
-		break;
+    case YPXFRD_GETMAP:
+      xdr_argument = (xdrproc_t) xdr_ypxfr_mapname;
+      xdr_result = (xdrproc_t) xdr_xfr;
+      local = (char *(*)(char *, struct svc_req *)) ypxfrd_getmap_1_svc;
+      break;
 
-	default:
-		svcerr_noproc(transp);
-		_rpcsvcdirty = 0;
-		return;
-	}
-	(void) memset((char *)&argument, 0, sizeof (argument));
-	if (!svc_getargs(transp, xdr_argument, (caddr_t) &argument)) {
-		svcerr_decode(transp);
-		_rpcsvcdirty = 0;
-		return;
-	}
-	result = (*local)((char *)&argument, rqstp);
-	if (result != NULL && !svc_sendreply(transp, xdr_result, result)) {
-		svcerr_systemerr(transp);
-	}
-	if (!svc_freeargs(transp, xdr_argument, (caddr_t) &argument)) {
-		_msgout("unable to free arguments");
-		exit(1);
-	}
-	_rpcsvcdirty = 0;
-	return;
+    default:
+      svcerr_noproc(transp);
+      _rpcsvcdirty = 0;
+      return;
+    }
+  memset(&argument, 0, sizeof (argument));
+  if (!svc_getargs(transp, xdr_argument, (caddr_t) &argument))
+    {
+      svcerr_decode(transp);
+      _rpcsvcdirty = 0;
+      return;
+    }
+  result = (*local)((char *)&argument, rqstp);
+  if (result != NULL && !svc_sendreply (transp, xdr_result, result))
+    svcerr_systemerr (transp);
+
+  if (!svc_freeargs (transp, xdr_argument, (caddr_t) &argument))
+    {
+      _msgout ("unable to free arguments");
+      exit (1);
+    }
+  _rpcsvcdirty = 0;
+  return;
 }
